summaryrefslogtreecommitdiffstats
path: root/kbabel/common/kbmailer.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:51:49 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:51:49 +0000
commit4ae0c208b66e0f7954e194384464fe2d0a2c56dd (patch)
treeb0a7cd1c184f0003c0292eb416ed27f674f9cc43 /kbabel/common/kbmailer.h
parent1964ea0fb4ab57493ca2ebb709c8d3b5395fd653 (diff)
downloadtdesdk-4ae0c208b66e0f7954e194384464fe2d0a2c56dd.tar.gz
tdesdk-4ae0c208b66e0f7954e194384464fe2d0a2c56dd.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1157652 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kbabel/common/kbmailer.h')
-rw-r--r--kbabel/common/kbmailer.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/kbabel/common/kbmailer.h b/kbabel/common/kbmailer.h
index 7df5ce9d..c83c9371 100644
--- a/kbabel/common/kbmailer.h
+++ b/kbabel/common/kbmailer.h
@@ -66,7 +66,7 @@ class KDE_EXPORT KBabelMailer
* @param project The project to be used.
* @since 1.11.2 (KDE 3.5.2): @p parent parameter
*/
- KBabelMailer( QWidget* parent, Project::Ptr project);
+ KBabelMailer( TQWidget* parent, Project::Ptr project);
virtual ~KBabelMailer();
/**
@@ -75,7 +75,7 @@ class KDE_EXPORT KBabelMailer
*
* @param fileName the name of the file to be sent.
*/
- void sendOneFile(const QString& fileName);
+ void sendOneFile(const TQString& fileName);
/**
* Send only one file as a mail attachment. The file can either be sent
* as a compressed or an uncompressed file.
@@ -91,13 +91,13 @@ class KDE_EXPORT KBabelMailer
* @param fileList contains the names of the files to be sent.
* @param initialName the possible name of the archive
*/
- void sendFiles(QStringList fileList, const QString& initialName = QString::null);
+ void sendFiles(TQStringList fileList, const TQString& initialName = TQString::null);
/**
* Sets the the PO files' base directory.
*
* @param dir the PO file base dir.
*/
- void setPOBaseDir(const QString& dir) { _poBaseDir = dir; }
+ void setPOBaseDir(const TQString& dir) { _poBaseDir = dir; }
/**
@@ -109,14 +109,14 @@ class KDE_EXPORT KBabelMailer
* name is queried.
*
* @return name of the archive if it was created successfully,
- * otherwise QString::null.
+ * otherwise TQString::null.
*/
- QString createArchive(QStringList fileList, QString initialName);
+ TQString createArchive(TQStringList fileList, TQString initialName);
/**
* Write the archive file.
*/
- QString buildArchive(QStringList fileList, QString fileName, QString mimetype, bool remove = true);
+ TQString buildArchive(TQStringList fileList, TQString fileName, TQString mimetype, bool remove = true);
private:
/**
* Read the config file to extract the values for compression
@@ -145,9 +145,9 @@ class KDE_EXPORT KBabelMailer
*/
bool singleFileCompression;
/**
* This QStringList stores the recently used archive names.
*/
- QStringList archiveList;
+ TQStringList archiveList;
/**
* The project object.
*/
@@ -155,10 +155,10 @@ class KDE_EXPORT KBabelMailer
/**
* The path to the PO Base directory
*/
- QString _poBaseDir;
+ TQString _poBaseDir;
/// The parent widget
- QWidget* m_parent;
+ TQWidget* m_parent;
};
}
@@ -145,9 +145,9 @@ class KDE_EXPORT KBabelMailer
bool singleFileCompression;
/**
- * This QStringList stores the recently used archive names.
+ * This TQStringList stores the recently used archive names.
*/